`include "define.vh"
module top(
    clk,       // 时钟信号
    data_a,
    data_b,
    rstn,      // 复位信号（低电平有效）
	overflow,  // 溢出标志
	underflow, // 低于有效数值范围标志
	nan,       // NaN标志
	zero,      // 零标志
    division_by_zero, //除零
    result     // 计算结果
);
//**********************************************************************
// --- Input/Output Declaration
//**********************************************************************
	localparam NUM_DATA = 1024;
	input clk;
	input rstn;
	reg [31:0] mem_data_1 [0:NUM_DATA-1];
    reg [31:0] mem_data_2 [0:NUM_DATA-1];
	output reg   [31:0] data_a;
	output reg   [31:0] data_b;
    output wire   [31:0] result;
    output overflow,underflow,nan,zero,division_by_zero;
    reg start;
	reg [$clog2(NUM_DATA+1):0] i_data;
	
//**********************************************************************
// --- Main core
//**********************************************************************	
	FP_Div_Top FP_Div(
        .clk        (clk),       // 时钟信号
        .rstn       (rstn),      // 复位信号（低电平有效）
        `ifdef CE
        .ce         (1'b1),        // 时钟使能信号
        `endif
        .data_a     (data_a),    // 输入数据A
        .data_b     (data_b),    // 输入数据B
        `ifdef OVERFLOW
        .overflow   (overflow),  // 溢出标志
        `endif
        `ifdef UNDERFLOW
        .underflow  (underflow), // 低于有效数值范围标志
        `endif
        `ifdef NAN
        .nan        (nan),       // NaN标志
        `endif
        `ifdef ZERO
        .zero       (zero),      // 零标志
        `endif
        `ifdef DIV_BY_ZERO
        .division_by_zero(division_by_zero), //除零
        `endif 
        .result     (result)     // 计算结果
	);
	
	always @(posedge clk or negedge rstn) begin
		if(!rstn) begin
			i_data <= 0;
		end
		else if(start) begin
			i_data <= i_data + 1'b1;
		end
	end
	
	always @(posedge clk or negedge rstn) begin
		if(!rstn) begin
			data_a <= 0;
			data_b <= 0;
		end
		else if(start) begin
			data_a <= mem_data_1[i_data];
			data_b <= mem_data_2[i_data];
		end
	end
	
    always @(posedge clk) begin

        if(!rstn) begin
            start <= 0;
            
        end else begin
            start <= 1;
        end
    end


	initial begin
		$readmemh("../proj/src/data/x.dat",mem_data_1);
		$readmemh("../proj/src/data/y.dat",mem_data_2);
	end

endmodule
