`timescale 1ns / 1ps
`include "../proj/src/define/define.vh"

module tb();
//**********************************************************************
// --- Test Input/Output signal
//**********************************************************************	
reg clk;
reg rstn;

wire        [31:0]  		  result;
wire overflow, underflow, nan, zero, division_by_zero;
localparam CLK_PERIOD = 50.0;
//**********************************************************************
// --- Reset 
//**********************************************************************
initial begin
	rstn <= 1'b1;
	#(1.5*CLK_PERIOD) rstn <= 1'b0;
	#(CLK_PERIOD) rstn <= 1'b1;
end
//**********************************************************************	
// --- Clock Generate
//**********************************************************************
initial begin
	clk <= 1'b1;
	#(1.5*CLK_PERIOD) 
	forever #(CLK_PERIOD/2.0) clk = ~clk;
end
//**********************************************************************	
// --- Initial Block
//**********************************************************************
top top_tb(
        .clk        (clk),       // 时钟信号
        .rstn       (rstn),      // 复位信号（低电平有效）
        .data_a     (),    // 输入数据A
        .data_b     (),    // 输入数据B
        `ifdef OVERFLOW
        .overflow   (overflow),  // 溢出标志
        `endif
        `ifdef UNDERFLOW
        .underflow  (underflow), // 低于有效数值范围标志
        `endif
        `ifdef NAN
        .nan        (nan),       // NaN标志
        `endif
        `ifdef ZERO
        .zero       (zero),      // 零标志
        `endif
        `ifdef DIV_BY_ZERO
        .division_by_zero(division_by_zero), //除零
        `endif 
        .result     (result)     // 计算结果
);

endmodule